@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef ALARM_LIST_DIALOG_H
@@ -32,6 +32,8 @@
 G_BEGIN_DECLS
 
 gboolean alarm_list_dialog_run (GtkWidget *parent, ECal *ecal, EAlarmList *list_store);
+GtkWidget *alarm_list_dialog_peek (ECal *ecal, EAlarmList *list_store);
+void alarm_list_dialog_set_client (GtkWidget *dlg_box, ECal *client);
 
 G_END_DECLS
 
