@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef COMP_EDITOR_H
@@ -65,6 +65,7 @@ typedef enum {
 	COMP_EDITOR_DELEGATE = 1<<2,
 	COMP_EDITOR_USER_ORG = 1<<3,
 	COMP_EDITOR_IS_ASSIGNED = 1<<4,
+	COMP_EDITOR_IS_SHARED = 1 << 5
 } CompEditorFlags;
 
 GtkType       comp_editor_get_type         (void);
@@ -99,13 +100,14 @@ ECal         *comp_editor_get_e_cal        (CompEditor             *editor);
 void          comp_editor_edit_comp        (CompEditor             *ee,
 					    ECalComponent           *comp);
 ECalComponent *comp_editor_get_comp        (CompEditor             *editor);
-ECalComponent *comp_editor_get_current_comp (CompEditor             *editor);
+ECalComponent *comp_editor_get_current_comp (CompEditor            *editor,
+					     gboolean              *correct);
 gboolean      comp_editor_save_comp        (CompEditor             *editor,
 					    gboolean                send);
 void          comp_editor_delete_comp      (CompEditor             *editor);
 gboolean      comp_editor_send_comp        (CompEditor             *editor,
 					    ECalComponentItipMethod  method);
-GSList        *comp_editor_get_mime_attach_list (CompEditor        *editor); 
+GSList        *comp_editor_get_mime_attach_list (CompEditor        *editor);
 gboolean      comp_editor_close            (CompEditor             *editor);
 void          comp_editor_focus            (CompEditor             *editor);
 
