@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_CAL_MODEL_H
@@ -156,7 +156,7 @@ GPtrArray * e_cal_model_get_object_array (ECalModel *model);
 void e_cal_model_set_instance_times (ECalModelComponent *comp_data, const icaltimezone *zone);
 void e_cal_model_set_search_query_with_time_range (ECalModel *model, const char *sexp, time_t start, time_t end);
 
-
+gboolean e_cal_model_test_row_editable (ECalModel *model, int row);
 
 G_END_DECLS
 
