@@ -15,16 +15,18 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef MISC_H
 #define MISC_H
 
 #include <glib.h>
+#include <time.h>
 
 gboolean string_is_empty (const char *value);
 char    *get_uri_without_password (const char *uri);
-
+gint get_position_in_array (GPtrArray *objects, gpointer item);
+char * calculate_time (time_t start, time_t end);
 #endif
