@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* e-corba-utils.h
- * 
+ *
  * Copyright (C) 2000  Ximian, Inc.
  * Author: Ettore Perazzoli <ettore@ximian.com>
  *
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_CORBA_UTILS_H
 #define E_CORBA_UTILS_H
 
-#include <orb/orbit.h>
+#include <orbit/orbit.h>
 
 const CORBA_char *e_safe_corba_string      (const char *s);
 CORBA_char       *e_safe_corba_string_dup  (const char *s);
