@@ -176,7 +176,7 @@ efh_gtkhtml_destroy(GtkHTML *html, EMFormatHTML *efh)
 	if (efh->priv->format_timeout_id != 0) {
 		g_source_remove(efh->priv->format_timeout_id);
 		efh->priv->format_timeout_id = 0;
-		mail_msg_free(efh->priv->format_timeout_msg);
+		mail_msg_unref(efh->priv->format_timeout_msg);
 		efh->priv->format_timeout_msg = NULL;
 	}
 
@@ -309,6 +309,12 @@ em_format_html_set_mark_citations(EMFormatHTML *emfh, int state, guint32 citatio
 	if (emfh->mark_citations ^ state || emfh->citation_colour != citation_colour) {
 		emfh->mark_citations = state;
 		emfh->citation_colour = citation_colour;
+
+		if (state)
+			emfh->text_html_flags |= CAMEL_MIME_FILTER_TOHTML_MARK_CITATION;
+		else
+			emfh->text_html_flags &= ~CAMEL_MIME_FILTER_TOHTML_MARK_CITATION;
+
 		em_format_redraw((EMFormat *)emfh);
 	}
 }
@@ -1205,7 +1211,7 @@ efh_builtin_init(EMFormatHTMLClass *efhc)
 
 /* Sigh, this is so we have a cancellable, async rendering thread */
 struct _format_msg {
-	struct _mail_msg msg;
+	MailMsg base;
 
 	EMFormatHTML *format;
 	EMFormat *format_source;
@@ -1215,14 +1221,15 @@ struct _format_msg {
 	CamelMimeMessage *message;
 };
 
-static char *efh_format_desc(struct _mail_msg *mm, int done)
+static gchar *
+efh_format_desc (struct _format_msg *m)
 {
 	return g_strdup(_("Formatting message"));
 }
 
-static void efh_format_do(struct _mail_msg *mm)
+static void
+efh_format_exec (struct _format_msg *m)
 {
-	struct _format_msg *m = (struct _format_msg *)mm;
 	struct _EMFormatHTMLJob *job;
 	struct _EMFormatPURITree *puri_level;
 	int cancelled = FALSE;
@@ -1307,10 +1314,9 @@ static void efh_format_do(struct _mail_msg *mm)
 	((EMFormat *)m->format)->pending_uri_level = puri_level;
 }
 
-static void efh_format_done(struct _mail_msg *mm)
+static void
+efh_format_done (struct _format_msg *m)
 {
-	struct _format_msg *m = (struct _format_msg *)mm;
-
 	d(printf("formatting finished\n"));
 
 	m->format->load_http_now = FALSE;
@@ -1318,10 +1324,9 @@ static void efh_format_done(struct _mail_msg *mm)
 	g_signal_emit_by_name(m->format, "complete");
 }
 
-static void efh_format_free(struct _mail_msg *mm)
+static void
+efh_format_free (struct _format_msg *m)
 {
-	struct _format_msg *m = (struct _format_msg *)mm;
-
 	d(printf("formatter freed\n"));
 	g_object_unref(m->format);
 	if (m->estream) {
@@ -1337,11 +1342,12 @@ static void efh_format_free(struct _mail_msg *mm)
 		g_object_unref(m->format_source);
 }
 
-static struct _mail_msg_op efh_format_op = {
-	efh_format_desc,
-	efh_format_do,
-	efh_format_done,
-	efh_format_free,
+static MailMsgInfo efh_format_info = {
+	sizeof (struct _format_msg),
+	(MailMsgDescFunc) efh_format_desc,
+	(MailMsgExecFunc) efh_format_exec,
+	(MailMsgDoneFunc) efh_format_done,
+	(MailMsgFreeFunc) efh_format_free
 };
 
 static gboolean
@@ -1352,7 +1358,7 @@ efh_format_timeout(struct _format_msg *m)
 	struct _EMFormatHTMLPrivate *p = efh->priv;
 
 	if (m->format->html == NULL) {
-		mail_msg_free(m);
+		mail_msg_unref(m);
 		return FALSE;
 	}
 
@@ -1380,7 +1386,7 @@ efh_format_timeout(struct _format_msg *m)
 	if (m->message == NULL) {
 		hstream = gtk_html_begin(efh->html);
 		gtk_html_stream_close(hstream, GTK_HTML_STREAM_OK);
-		mail_msg_free(m);
+		mail_msg_unref(m);
 		p->last_part = NULL;
 	} else {
 		if (p->last_part != m->message) {
@@ -1403,8 +1409,8 @@ efh_format_timeout(struct _format_msg *m)
 			p->last_part = m->message;
 		}
 
-		efh->priv->format_id = m->msg.seq;
-		e_thread_put(mail_thread_new, (EMsg *)m);
+		efh->priv->format_id = m->base.seq;
+		mail_msg_unordered_push (m);
 	}
 
 	efh->priv->format_timeout_id = 0;
@@ -1428,11 +1434,11 @@ static void efh_format_clone(EMFormat *emf, CamelFolder *folder, const char *uid
 		d(printf(" timeout for last still active, removing ...\n"));
 		g_source_remove(efh->priv->format_timeout_id);
 		efh->priv->format_timeout_id = 0;
-		mail_msg_free(efh->priv->format_timeout_msg);
+		mail_msg_unref(efh->priv->format_timeout_msg);
 		efh->priv->format_timeout_msg = NULL;
 	}
 
-	m = mail_msg_new(&efh_format_op, NULL, sizeof(*m));
+	m = mail_msg_new(&efh_format_info);
 	m->format = (EMFormatHTML *)emf;
 	g_object_ref(emf);
 	m->format_source = emfsource;
@@ -1484,22 +1490,34 @@ efh_format_text_header (EMFormatHTML *emfh, CamelStream *stream, const char *lab
 	else
 		html = mhtml = camel_text_to_html (value, emfh->text_html_flags, 0);
 
+	gboolean is_rtl = gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL;
 	if (emfh->simple_headers) {
 		fmt = "<b>%s</b>: %s<br>";
 	} else {
 		if (flags & EM_FORMAT_HTML_HEADER_NOCOLUMNS) {
-			if (flags & EM_FORMAT_HEADER_BOLD)
+			if (flags & EM_FORMAT_HEADER_BOLD) {
 				fmt = "<tr><td><b>%s:</b> %s</td></tr>";
-			else
+			} else {
 				fmt = "<tr><td>%s: %s</td></tr>";
+			}
 		} else if (flags & EM_FORMAT_HTML_HEADER_NODEC) {
-			fmt = "<tr><th align=\"right\" valign=\"top\" nowrap>%s<b>&nbsp;</b></th><td valign=top>%s</td></tr>";
-		} else {
-
-			if (flags & EM_FORMAT_HEADER_BOLD)
-				fmt = "<tr><th align=\"right\" valign=\"top\" nowrap>%s:<b>&nbsp;</b></th><td>%s</td></tr>";
+			if (is_rtl)
+				fmt = "<tr><td align=\"right\" valign=\"top\" width=\"100%%\">%2$s</td><th valign=top align=\"left\" nowrap>%1$s<b>&nbsp;</b></th></tr>";
 			else
-				fmt = "<tr><td align=\"right\" valign=\"top\" nowrap>%s:<b>&nbsp;</b></td><td>%s</td></tr>";
+				fmt = "<tr><th align=\"right\" valign=\"top\" nowrap>%s<b>&nbsp;</b></th><td valign=top>%s</td></tr>";
+		} else {
+			
+			if (flags & EM_FORMAT_HEADER_BOLD) {
+				if (is_rtl)
+					fmt = "<tr><td align=\"right\" valign=\"top\" width=\"100%%\">%2$s</td><th align=\"left\" nowrap>%1$s:<b>&nbsp;</b></th></tr>";
+				else
+					fmt = "<tr><th align=\"right\" valign=\"top\" nowrap>%s:<b>&nbsp;</b></th><td>%s</td></tr>";
+			} else {
+				if (is_rtl)
+					fmt = "<tr><td align=\"right\" valign=\"top\" width=\"100%\">%2$s</td><td align=\"left\" nowrap>%1$s:<b>&nbsp;</b></td></tr>";
+				else
+					fmt = "<tr><td align=\"right\" valign=\"top\" nowrap>%s:<b>&nbsp;</b></td><td>%s</td></tr>";
+			}
 		}
 	}
 
@@ -1838,7 +1856,10 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 
 		if (header_sender && header_from && mail_from_delegate) {
 			camel_stream_printf(stream, "<tr><td><table border=1 width=\"100%%\" cellspacing=2 cellpadding=2><tr>");
-			camel_stream_printf(stream, "<td align=\"left\" width=\"100%%\">");
+			if(gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL)
+				camel_stream_printf (stream, "<td align=\"right\" width=\"100%%\">");
+			else
+				camel_stream_printf (stream, "<td align=\"left\" width=\"100%%\">");
 			/* To translators: This message suggests to the receipients that the sender of the mail is
 			   different from the one listed in From field.
 			*/
@@ -1853,7 +1874,10 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 	g_free (header_sender);
 	g_free (header_from);
 
-	camel_stream_printf(stream, "<tr><td><table border=0 cellpadding=\"0\">\n");
+	if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL)
+		camel_stream_printf (stream, "<tr><td><table width=\"100%%\" border=0 cellpadding=\"0\">\n");
+	else
+		camel_stream_printf (stream, "<tr><td><table border=0 cellpadding=\"0\">\n");
 
 	/* dump selected headers */
 	h = (EMFormatHeader *)emf->header_list.head;
@@ -1892,7 +1916,7 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 					gchar *cp;
 
 					/* Skip over spaces */
-					for (cp = header->name; *cp == ' '; cp++);
+					for (cp = header->value; *cp == ' '; cp++);
 					face_header_value = g_base64_decode (cp, &face_header_len);
 					face_header_value = g_realloc (face_header_value, face_header_len + 1);
 					face_header_value[face_header_len] = 0;
