@@ -80,6 +80,7 @@ struct _EMMailerPrefs {
 	struct _GtkOptionMenu *charset;
 	struct _GtkToggleButton *citation_highlight;
 	struct _GtkColorButton *citation_color;
+	struct _GtkToggleButton *enable_search_folders;
 	struct _GtkToggleButton *magic_spacebar;
 
 	/* Deleting Mail */
@@ -103,10 +104,11 @@ struct _EMMailerPrefs {
 
 	/* Labels and Colours tab */
 	struct _GtkWidget *label_add;
+	struct _GtkWidget *label_edit;
 	struct _GtkWidget *label_remove;
-	struct _GtkWidget *label_color;
 	struct _GtkWidget *label_tree;
 	struct _GtkListStore *label_list_store;
+	guint labels_change_notify_id; /* mail_config's notify id */
 
 	/* Headers tab */
 	struct _GtkButton *add_header;
@@ -121,12 +123,20 @@ struct _EMMailerPrefs {
 	struct _GtkToggleButton *check_incoming;
 	struct _GtkToggleButton *empty_junk;
 	struct _GtkOptionMenu *empty_junk_days;
-
+	
 	struct _GtkToggleButton *sa_local_tests_only;
 	struct _GtkToggleButton *sa_use_daemon;
 	struct _GtkComboBox *default_junk_plugin;
 	struct _GtkLabel *plugin_status;
 	struct _GtkImage *plugin_image;
+
+	struct _GtkToggleButton *junk_header_check;
+	struct _GtkTreeView *junk_header_tree;
+	struct _GtkListStore *junk_header_list_store;	
+	struct _GtkButton *junk_header_add;
+	struct _GtkButton *junk_header_remove;
+	struct _GtkToggleButton *junk_book_lookup;
+
 };
 
 struct _EMMailerPrefsClass {
